<div align="center">
  <h1 align="center">
    <img src="https://cndaqiang.github.io/wzry.doc/wzry.favicon.png" width="140">
    <br/>
    autowzry · 农活自动化助手
  </h1>
</div>
<div align="center">
  <img alt="autowzry Release" src="https://img.shields.io/github/v/release/cndaqiang/autowzry?style=flat-square&color=ff7fbf&label=autowzry" />
  <img alt="Stars" src="https://img.shields.io/github/stars/cndaqiang/autowzry?style=flat-square&color=66bb6a&label=Stars" />
</div>

<div align="center">
使用方法, 请访问: <a href="https://wzry-doc.pages.dev/guide/install/">安装指南</a>|<a href="https://wzrydoc.readthedocs.io/">备用指南</a>|<a href="https://www.bilibili.com/video/BV1JmcteBEUS">视频教程</a>.
<br/>
遇到问题, 请在提问前查看: <a href="https://wzry-doc.pages.dev/qa/qa/">常见问题</a>.
<br/>
</div>

## 免责声明
[autowzry](https://github.com/cndaqiang/autowzry) 是基于 [airtest-mobileauto](https://github.com/cndaqiang/airtest_mobileauto) 开发的农活自动化免费开源脚本。
**7*24h 完全无人值守运行**，支持自动启动模拟器、更新游戏、错误自修复、全自动对战及礼包领取，解放双手专注生活。

本项目通过图像识别、模拟人手点击的方式实现自动化, 不会修改读取游戏数据。

虽然理论上没有封号风险，但使用本项目的后果需由用户自行承担。

⚠️ **本项目严禁用于开发人人博弈的对战模式，请勿影响其他玩家的正常游戏体验！** ⚠️  

**本项目完全免费，未在任何平台或渠道提供付费服务或收费支持。请勿相信任何形式的收费信息！**  

⚠️ **本项目没有任何群聊，所有讨论仅限于 [助手 的 GitHub 主页](https://github.com/cndaqiang/autowzry)！** ⚠️  


## 致谢
- 灵感和支持来自以下项目：  
  - [airtest_mobileauto](https://github.com/cndaqiang/airtest_mobileauto)  
  - [WZRY_AirtestIDE](https://github.com/XRSec/WZRY_AirtestIDE)  
  - [Airtest Project](https://github.com/AirtestProject)
  - [StarRailAssistant](https://github.com/Starry-Wind/StarRailAssistant)
  - [March7thAssistant](https://github.com/moesnow/March7thAssistant)

- 感谢所有提问 issue 和为本项目打星的用户!
- 感谢b站的老哥们点赞推广!

## 开源协议

该项目采用 [GNU General Public License v3.0](https://www.gnu.org/licenses/gpl-3.0.html) 许可证进行开源。